@@ -21,7 +21,7 @@ def prepare_data(play_dir, pdb_dir):
     mols = [i for i in Chem.SDMolSupplier(ligands)]
     mols_h = [i for i in Chem.SDMolSupplier(ligands, removeHs=False)]
     ref = mols[:][0]
-    atoms = [i for i in range(ref.GetNumAtoms())]
+    ref_core = [i for i in range(ref.GetNumAtoms())]
     mols_pair = list(zip(mols, mols_h))
     random.shuffle(mols_pair)
 
@@ -32,9 +32,10 @@ def prepare_data(play_dir, pdb_dir):
     for idx, mol_pair in enumerate(mols_pair):
         mol, mol_h = mol_pair
         name = str(idx + 1)
+        mol_core = mol.GetSubstructMatch(ref)
         # rename mols
         mol_h.SetProp('_Name', name)
-        atomMaps = list(zip(atoms, atoms))
+        atomMaps = list(zip(mol_core, ref_core))
         rmsd = calcRMSD(mol, ref, atomMaps)
         rmsd_value[name] = rmsd
         # print(idx + 1, rmsd)
